|build| |documentation| |coverage| |requirements|


Micromouse Maze Simulator
=========================

The simulator acts as a server and can load different mazes. Any client can
connect to it to ask for the current position walls, move from one cell to
another and visualize the simulated micromouse state. `Watch it in action!
<https://youtu.be/6Om6xij6LAw>`_

Install it with::

   pip install mmsim

Run it with::

   mmsim

For further details and instructions on how to implement a client, refer to
the `Micromouse Maze Simulator documentation <https://mmsim.readthedocs.io>`_.


.. |build|
   image:: https://api.travis-ci.org/Theseus/mmsim.svg?branch=master
      :target: https://travis-ci.org/Theseus/mmsim
      :alt: Build badge
.. |documentation|
   image:: https://readthedocs.org/projects/mmsim/badge/?version=stable
      :target: https://mmsim.readthedocs.io/
      :alt: Documentation badge
.. |coverage| image:: https://codecov.io/github/Theseus/mmsim/coverage.svg?branch=master
      :target: https://codecov.io/github/Theseus/mmsim
      :alt: Coverage badge
.. |requirements| image:: https://requires.io/github/Theseus/mmsim/requirements.svg
      :target: https://requires.io/github/Theseus/mmsim/requirements/
      :alt: Requirements badge
